==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/GrupaUprawnienieKatUslugKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.TypUprawnieniaKatUslug;
import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class GrupaUprawnienieKatUslugKey extends GenericDPSObject {
    /**
     * GRUPA_UPRAWNIENIE_KAT_USLUG.CZYNNOSC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long czynnoscId;

    /**
     * GRUPA_UPRAWNIENIE_KAT_USLUG.GRUPA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long grupaId;

    /**
     * GRUPA_UPRAWNIENIE_KAT_USLUG.TYP_UPRAWNIENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypUprawnieniaKatUslug typUprawnienia;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return GRUPA_UPRAWNIENIE_KAT_USLUG.CZYNNOSC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getCzynnoscId() {
        return czynnoscId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:41
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * GRUPA_UPRAWNIENIE_KAT_USLUG.CZYNNOSC_ID
     *
     * @param czynnoscId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setCzynnoscId(Long czynnoscId) {
        this.czynnoscId = czynnoscId;
    }

    /**
     * @return GRUPA_UPRAWNIENIE_KAT_USLUG.GRUPA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getGrupaId() {
        return grupaId;
    }

    /**
     * GRUPA_UPRAWNIENIE_KAT_USLUG.GRUPA_ID
     *
     * @param grupaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setGrupaId(Long grupaId) {
        this.grupaId = grupaId;
    }

    /**
     * @return GRUPA_UPRAWNIENIE_KAT_USLUG.TYP_UPRAWNIENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypUprawnieniaKatUslug getTypUprawnienia() {
        return typUprawnienia;
    }

    /**
     * GRUPA_UPRAWNIENIE_KAT_USLUG.TYP_UPRAWNIENIA
     *
     * @param typUprawnienia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTypUprawnienia(TypUprawnieniaKatUslug typUprawnienia) {
        this.typUprawnienia = typUprawnienia;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        GrupaUprawnienieKatUslugKey other = (GrupaUprawnienieKatUslugKey) that;
        return (this.getCzynnoscId() == null ? other.getCzynnoscId() == null : this.getCzynnoscId().equals(other.getCzynnoscId()))
            && (this.getGrupaId() == null ? other.getGrupaId() == null : this.getGrupaId().equals(other.getGrupaId()))
            && (this.getTypUprawnienia() == null ? other.getTypUprawnienia() == null : this.getTypUprawnienia().equals(other.getTypUprawnienia()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getCzynnoscId() == null) ? 0 : getCzynnoscId().hashCode());
        result = prime * result + ((getGrupaId() == null) ? 0 : getGrupaId().hashCode());
        result = prime * result + ((getTypUprawnienia() == null) ? 0 : getTypUprawnienia().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", czynnoscId=").append(czynnoscId);
        sb.append(", grupaId=").append(grupaId);
        sb.append(", typUprawnienia=").append(typUprawnienia);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/GrupaUprawnienieKatUslugKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.TypUprawnieniaKatUslug;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class GrupaUprawnienieKatUslugKey extends GenericDPSObject {
    /**
     * GRUPA_UPRAWNIENIE_KAT_USLUG.CZYNNOSC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long czynnoscId;

    /**
     * GRUPA_UPRAWNIENIE_KAT_USLUG.GRUPA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long grupaId;

    /**
     * GRUPA_UPRAWNIENIE_KAT_USLUG.TYP_UPRAWNIENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypUprawnieniaKatUslug typUprawnienia;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return GRUPA_UPRAWNIENIE_KAT_USLUG.CZYNNOSC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getCzynnoscId() {
        return czynnoscId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:45
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * GRUPA_UPRAWNIENIE_KAT_USLUG.CZYNNOSC_ID
     *
     * @param czynnoscId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setCzynnoscId(Long czynnoscId) {
        this.czynnoscId = czynnoscId;
    }

    /**
     * @return GRUPA_UPRAWNIENIE_KAT_USLUG.GRUPA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getGrupaId() {
        return grupaId;
    }

    /**
     * GRUPA_UPRAWNIENIE_KAT_USLUG.GRUPA_ID
     *
     * @param grupaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setGrupaId(Long grupaId) {
        this.grupaId = grupaId;
    }

    /**
     * @return GRUPA_UPRAWNIENIE_KAT_USLUG.TYP_UPRAWNIENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypUprawnieniaKatUslug getTypUprawnienia() {
        return typUprawnienia;
    }

    /**
     * GRUPA_UPRAWNIENIE_KAT_USLUG.TYP_UPRAWNIENIA
     *
     * @param typUprawnienia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTypUprawnienia(TypUprawnieniaKatUslug typUprawnienia) {
        this.typUprawnienia = typUprawnienia;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        GrupaUprawnienieKatUslugKey other = (GrupaUprawnienieKatUslugKey) that;
        return (this.getCzynnoscId() == null ? other.getCzynnoscId() == null : this.getCzynnoscId().equals(other.getCzynnoscId()))
            && (this.getGrupaId() == null ? other.getGrupaId() == null : this.getGrupaId().equals(other.getGrupaId()))
            && (this.getTypUprawnienia() == null ? other.getTypUprawnienia() == null : this.getTypUprawnienia().equals(other.getTypUprawnienia()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getCzynnoscId() == null) ? 0 : getCzynnoscId().hashCode());
        result = prime * result + ((getGrupaId() == null) ? 0 : getGrupaId().hashCode());
        result = prime * result + ((getTypUprawnienia() == null) ? 0 : getTypUprawnienia().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", czynnoscId=").append(czynnoscId);
        sb.append(", grupaId=").append(grupaId);
        sb.append(", typUprawnienia=").append(typUprawnienia);
        sb.append("]");
        return sb.toString();
    }
}
